@@ -10,7 +10,7 @@ from .update import UpdateHandler
 
 
 class QueryHandler(UpdateHandler, ABC):
-    def __init__(self, button: str | list[str]) -> None:
+    def __init__(self, button: str | list[str] | None = None) -> None:
         self.on_button = button
         super().__init__()
 
@@ -18,6 +18,8 @@ class QueryHandler(UpdateHandler, ABC):
         return ext.CallbackQueryHandler(self.handle, self._filter)
 
     def _filter(self, callback_data: object) -> bool:
+        if self.on_button is None:
+            return True
         if not isinstance(callback_data, str):
             raise CallbackDataError(callback_data)
         return callback_data in listify(self.on_button)
