@@ -1,18 +1,17 @@
 import telegram
 
-from botty.errors import FieldError
+from botty.telegram_object import TelegramObject
 
 
-class Query:
+class Query(TelegramObject):
+    raw: telegram.CallbackQuery
+
     def __init__(self, raw: telegram.CallbackQuery) -> None:
-        self.raw = raw
+        super().__init__(raw)
 
     @property
     def data(self) -> str:
-        value = self.raw.data
-        if value is None:
-            raise FieldError(self.raw, "data")
-        return value
+        return self.get_validated_field("data", self.raw.data)
 
     async def answer(self, text: str, *, show_alert: bool = False) -> bool:
         return await self.raw.answer(text, show_alert)
